@@ -61,11 +61,23 @@ class Topic(MetricsLayerBase):
 
     @property
     def model(self):
-        return self.project.get_model(self.model_name)
+        try:
+            return self.project.get_model(self.model_name)
+        except AccessDeniedOrDoesNotExistException as e:
+            e.message = str(e) + f" in topic {self.name}"
+            raise e
 
     @property
     def hidden(self):
-        return bool(self._definition.get("hidden", False))
+        try:
+            model_is_hidden = self.model.hidden
+        except Exception:
+            model_is_hidden = False
+        return bool(self._definition.get("hidden", False)) or model_is_hidden
+
+    @property
+    def base_view(self):
+        return str(self._definition.get("base_view")).lower()
 
     def _views(self):
         topic_view_names = [self.base_view]
@@ -83,6 +95,21 @@ class Topic(MetricsLayerBase):
 
         return topic_views
 
+    def from_view_references(self):
+        if self.views and isinstance(self.views, dict):
+            from_view_names = set(
+                [v["from"] for k, v in self.views.items() if isinstance(v, dict) and "from" in v]
+            )
+            from_views = []
+            for view_name in from_view_names:
+                try:
+                    view = self.project.get_view(view_name)
+                    from_views.append(view)
+                except AccessDeniedOrDoesNotExistException:
+                    pass
+            return from_views
+        return []
+
     def _error(self, element, error, extra: dict = {}):
         line, column = self.line_col(element)
         return {
@@ -140,12 +167,12 @@ class Topic(MetricsLayerBase):
             )
 
         if "base_view" in self._definition:
-            if not isinstance(self.base_view, str):
+            if not isinstance(self._definition["base_view"], str):
                 errors.append(
                     self._error(
-                        self.base_view,
+                        self._definition["base_view"],
                         (
-                            f"The base_view property, {self.base_view} must be a string"
+                            f"The base_view property, {self._definition['base_view']} must be a string"
                             f" in the topic {self.label}"
                         ),
                     )
